@@ -97,18 +97,49 @@
                 tests: {}
             });</script>
 <script type="text/javascript" src="http://spin.js.org/spin.js"></script>
+<script type="text/javascript" src="http://digitalheroes.agence-ultramedia.com/wp-content/themes/emag_new/js/fancybox/loadingoverlay.min.js"></script>
 <script>
  jQuery(document).ready(function ($) {
 /*on enleve les items deja retirer du menu qui apparaisse toujours avec des id vide, tabindex pou garder le 1er item du menu-principal*/
-	$("#menu-menu-principal li:not([id]) a[tabindex!=0]").remove();
+	
+//$("#menu-menu-principal li:not([id]) a[tabindex!=0]").remove();
 
  });
 </script>
 
+<script>
+/*jQuery( document ).ready(function($) {
+  $( "body" ).on("click",".fancybox-button", function() {
+
+$.LoadingOverlay("show",{
+	zIndex  : 9999999,
+        color   : "rgba(0, 0, 0, 0.9)",
+        image   : "http://digitalheroes.agence-ultramedia.com/wp-content/themes/emag_new/js/fancybox/rolling.gif"
+});*/
+
+// Hide it after 3 seconds
+
+/*setTimeout(function(){
+    $.LoadingOverlay("hide");
+}, 3000);*/
+
+
+/*alert('test');
+$(".fancybox-inner").LoadingOverlay("show");
+$(".fancybox-inner").LoadingOverlay("show");*/
+
+
+// Here we might call the "hide" action 2 times, or simply set the "force" parameter to true:
+/*$(".fancybox-inner").LoadingOverlay("hide", true);*/
+ /*});
+});*/
+</script>
+
+
         <?php echo GenererFichiersCSS(); ?>
     </head>
     <body <?php body_class(); ?>>
-
+	
         <?php
         $current_numero = getCurrentNumero();
         $num_colors = get_option('numero_colors');
@@ -207,6 +238,7 @@
             $link_next = $tree_menu[$next]['url'];
         }
         ?>
+	
         <header>
             <nav class="navbar navbar-inverse navbar-static-top" role="navigation">
                 <div class="navbar-header">
